Hamiltonian Builder
-------------------

The HamiltonianBuilder takes an input SCF object,
and outputs coefficients for a second-quantised Hamiltonian.

Note it can be used with any PySCF SCF object,
not just those which have been embedded with Nbed.

.. automodule:: nbed.ham_builder
   :members:
   :undoc-members:
   :show-inheritance:
